autocapitalize function
Controls whether and how text input is automatically capitalized as it is entered/edited by the user. It can have the following values:
offornone, no autocapitalization is applied (all letters default to lowercase)onorsentences, the first letter of each sentence defaults to a capital letter; all other letters default to lowercasewords, the first letter of each word defaults to a capital letter; all other letters default to lowercasecharacters, all letters should default to uppercase
Implementation
Attribute<GlobalHTMLAttribute> autocapitalize(String value) {
return Attribute('autocapitalize', value);
}