className function
A space-separated list of the classes of the element. Classes allows CSS and JavaScript to select and access specific elements via the class selectors or functions like the method Document.getElementsByClassName().
Implementation
Attribute<GlobalHTMLAttribute> className(String value) {
return Attribute('class', value);
}