itemtype function
Specifies the URL of the vocabulary that will be used to define itemprops (item properties) in the data structure. [itemscope](https://developer.mozilla.org/docs/Web/HTML/Global_attributes#attr-itemscope) is used to set the scope of where in the data structure the vocabulary set by itemtype will be active.
Implementation
Attribute<GlobalHTMLAttribute> itemtype(String value) {
return Attribute('itemtype', value);
}